@@ -20,22 +20,33 @@ cat("*** This is a 2-treatment, 2-sequence, and 2-period crossover single dose d
 }
 cat("\n")
 
-cat("  Statistical analysis (ANOVA(lm))                  \n")
-cat("----------------------------------------------------\n")
+cat("   Statistical analysis (ANOVA(lm))                  \n")
+cat("-----------------------------------------------------------\n")
 if(multiple){
-cat("  Dependent Variable: Cmax_ss                       \n")
+cat("   Dependent Variable: Cmax_ss                       \n")
 cat("\n")
-cat("Type I SS\n")
 Cmax_ss<- lm(log(Cmax_ss) ~ seq + subj:seq + prd + drug , data=Data)
 BearAnova=anova(Cmax_ss)
-show(BearAnova)
+row.names(BearAnova)[4]="subj(seq)"
+show(BearAnova[2:5,])
 cat("\n")
-cat("Type III SS\n")
-Cmax_ss_drop1 <- drop1(Cmax_ss)
-show(Cmax_ss_drop1)
+colnames(BearAnova)<- c(" DF","   Type I SS", " Mean Square", " F Value", " Pr > F")
+show(BearAnova[2:4,])
 cat("\n")
-cat("Tests of Hypothesis for SUBJECT(SEQUENCE) as an error term\n")
-print(summary(aov(Cmax_ss ~ prd*drug + Error(subj) , data=Data)))
+colnames(BearAnova)<- c(" DF"," Type III SS", " Mean Square", " F Value", " Pr > F")
+show(BearAnova[2:4,])
+cat("-----------------------------------------------------------\n")
+#
+# to adpat to SAS output
+#
+cat("\n")
+cat("Tests of Hypothesis using the Type I MS for \n")
+cat("SUBJECT(SEQUENCE) as an error term\n")
+show(summary(aov(Cmax_ss ~ seq, data=Data)))
+cat("\n")
+cat("Tests of Hypothesis using the Type III MS for\n")
+cat("SUBJECT(SEQUENCE) as an error term\n")
+show(summary(aov(Cmax_ss ~ seq, data=Data)))
 ###
 ### the following is the same as Cmax_ss<- lm(log(Cmax_ss) ~ seq + subj:seq + prd + drug , data=Data)!
 ### the reason to do this is that we don't have to re-write more codes (around lines 277- 408) for nultiple-dose study;
@@ -45,56 +56,91 @@ print(summary(aov(Cmax_ss ~ prd*drug + Error(subj) , data=Data)))
 Cmax<- lm(Cmax ~ seq + subj:seq + prd + drug , data=TotalData)
 }
 else{
-cat("  Dependent Variable: Cmax                       \n")
+cat("   Dependent Variable: Cmax                       \n")
 cat("\n")
-cat("Type I SS\n")
 Cmax<- lm(Cmax ~ seq + subj:seq + prd + drug, data=TotalData)
 BearAnova=anova(Cmax)
-show(BearAnova)
+row.names(BearAnova)[4]="subj(seq)"
+show(BearAnova[2:5,])
 cat("\n")
-cat("Type III SS\n")
-Cmax_drop1 <- drop1(Cmax, test="F")
-show(Cmax_drop1)
+colnames(BearAnova)<- c(" DF","   Type I SS", " Mean Square", " F Value", " Pr > F")
+show(BearAnova[2:4,])
 cat("\n")
-cat("Tests of Hypothesis for SUBJECT(SEQUENCE) as an error term\n")
-print(summary(aov(Cmax ~ prd*drug + Error(subj) , data=TotalData)))
+colnames(BearAnova)<- c(" DF"," Type III SS", " Mean Square", " F Value", " Pr > F")
+show(BearAnova[2:4,])
+cat("-----------------------------------------------------------\n")
+#
+# to adpat to SAS output
+#
+cat("---\n")
+cat("Tests of Hypothesis using the Type I MS for \n")
+cat("SUBJECT(SEQUENCE) as an error term\n")
+show(summary(aov(Cmax ~ seq, data=TotalData)))
+cat("---\n")
+cat("Tests of Hypothesis using the Type III MS for\n")
+cat("SUBJECT(SEQUENCE) as an error term\n")
+show(summary(aov(Cmax ~ seq, data=TotalData)))
+cat("---\n")
+cat("Sum Sq. = Type III SS\n")
 }
 cat("\n")
 cat("\n")
 
 #GLM_AUC0t.txt
-cat("  Statistical analysis (ANOVA(lm))               \n")
-cat("-------------------------------------------------\n")
+cat("   Statistical analysis (ANOVA(lm))               \n")
+cat("-----------------------------------------------------------\n")
 if(multiple){
-cat("  Dependent Variable: AUC(tau)ss                 \n")
+cat("   Dependent Variable: AUC(tau)ss                 \n")
 cat("\n")
-cat("Type I SS\n")
 AUCtau_ss<- lm(AUCtau_ss ~ seq + subj:seq + prd + drug , data=Data)
 BearAnova=anova(AUCtau_ss)
-show(BearAnova)
+row.names(BearAnova)[4]="subj(seq)"
+show(BearAnova[2:5,])
 cat("\n")
-cat("Type III SS\n")
-AUCtau_ss_drop1 <- drop1(AUCtau_ss)
-show(AUCtau_ss_drop1)
+colnames(BearAnova)<- c(" DF","   Type I SS", " Mean Square", " F Value", " Pr > F")
+show(BearAnova[2:4,])
 cat("\n")
-cat("Tests of Hypothesis for SUBJECT(SEQUENCE) as an error term\n")
-print(summary(aov(AUCtau_ss ~ prd*drug + Error(subj) , data=Data)))
+colnames(BearAnova)<- c(" DF"," Type III SS", " Mean Square", " F Value", " Pr > F")
+show(BearAnova[2:4,])
+cat("-----------------------------------------------------------\n")
+#
+# to adpat to SAS output
+#
+cat("\n")
+cat("Tests of Hypothesis using the Type I MS for \n")
+cat("SUBJECT(SEQUENCE) as an error term\n")
+show(summary(aov(AUCtau_ss ~ seq, data=Data)))
+cat("\n")
+cat("Tests of Hypothesis using the Type III MS for\n")
+cat("SUBJECT(SEQUENCE) as an error term\n")
+show(summary(aov(AUCtau_ss ~ seq, data=Data)))
 AUC0t<- lm(AUC0t ~ seq + subj:seq + prd + drug , data=TotalData)
 }
 else{
-cat("  Dependent Variable: AUC0t                      \n")
+cat("   Dependent Variable: AUC0t                      \n")
 cat("\n")
-cat("Type I SS\n")
 AUC0t<- lm(AUC0t ~ seq + subj:seq + prd + drug , data=TotalData)
 BearAnova=anova(AUC0t)
-show(BearAnova)
+row.names(BearAnova)[4]="subj(seq)"
+show(BearAnova[2:5,])
 cat("\n")
-cat("Type III SS\n")
-AUC0t_drop1 <- drop1(AUC0t, test="F")
-show(AUC0t_drop1)
+colnames(BearAnova)<- c(" DF","   Type I SS", " Mean Square", " F Value", " Pr > F")
+show(BearAnova[2:4,])
 cat("\n")
-cat("Tests of Hypothesis for SUBJECT(SEQUENCE) as an error term\n")
-print(summary(aov(AUC0t ~ prd*drug + Error(subj) , data=TotalData)))
+colnames(BearAnova)<- c(" DF"," Type III SS", " Mean Square", " F Value", " Pr > F")
+show(BearAnova[2:4,])
+cat("-----------------------------------------------------------\n")
+#
+# to adpat to SAS output
+#
+cat("\n")
+cat("Tests of Hypothesis using the Type I MS for \n")
+cat("SUBJECT(SEQUENCE) as an error term\n")
+show(summary(aov(AUC0t ~ seq, data=TotalData)))
+cat("\n")
+cat("Tests of Hypothesis using the Type III MS for\n")
+cat("SUBJECT(SEQUENCE) as an error term\n")
+show(summary(aov(AUC0t ~ seq, data=TotalData)))
 }
 cat("\n")
 cat("\n")
@@ -103,80 +149,105 @@ if(multiple){
 }
 else{
 #GLM_AUC0INF.txt
-cat("  Statistical analysis (ANOVA(lm)and 90%CI)    \n")
-cat("-----------------------------------------------\n")
-cat("  Dependent Variable: AUC0INF                  \n")
+cat("   Statistical analysis (ANOVA(lm)and 90%CI)    \n")
+cat("-----------------------------------------------------------\n")
+cat("   Dependent Variable: AUC0INF                  \n")
 cat("\n")
-cat("Type I SS\n")
 AUC0INF<- lm(AUC0INF ~ seq + subj:seq + prd + drug , data=TotalData)
 BearAnova=anova(AUC0INF)
-show(BearAnova)
+row.names(BearAnova)[4]="subj(seq)"
+show(BearAnova[2:5,])
 cat("\n")
-cat("Type III SS\n")
-AUC0INF_drop1 <- drop1(AUC0INF, test="F")
-show(AUC0INF_drop1)
+colnames(BearAnova)<- c(" DF","   Type I SS", " Mean Square", " F Value", " Pr > F")
+show(BearAnova[2:4,])
 cat("\n")
-cat("Tests of Hypothesis for SUBJECT(SEQUENCE) as an error term\n")
-print(summary(aov(AUC0INF ~ prd*drug + Error(subj) , data=TotalData)))
+colnames(BearAnova)<- c(" DF"," Type III SS", " Mean Square", " F Value", " Pr > F")
+show(BearAnova[2:4,])
+cat("-----------------------------------------------------------\n")
+#
+# to adpat to SAS output
+#
 cat("\n")
+cat("Tests of Hypothesis using the Type I MS for \n")
+cat("SUBJECT(SEQUENCE) as an error term\n")
+show(summary(aov(AUC0INF ~ seq, data=TotalData)))
+cat("\n")
+cat("Tests of Hypothesis using the Type III MS for\n")
+cat("SUBJECT(SEQUENCE) as an error term\n")
+show(summary(aov(AUC0INF ~ seq, data=TotalData)))
 cat("\n")
 }
 #lnCmax or lnCmax_ss
 
-cat("  Statistical analysis (ANOVA(lm))    \n")
-cat("--------------------------------------\n")
+cat("   Statistical analysis (ANOVA(lm))    \n")
+cat("-----------------------------------------------------------\n")
 if(multiple){
-cat("  Dependent Variable: log(Cmax_ss)    \n")
+cat("   Dependent Variable: log(Cmax_ss)    \n")
 cat("\n")
-cat("Type I SS\n")
 lnCmax_ss<- lm(log(Cmax_ss) ~ seq + subj:seq + prd + drug , data=Data)
 BearAnova=anova(lnCmax_ss)
-show(BearAnova)
+row.names(BearAnova)[4]="subj(seq)"
+show(BearAnova[2:5,])
 cat("\n")
-cat("Type III SS\n")
-lnCmax_ss_drop1 <- drop1(lnCmax_ss, test="F")
-show(lnCmax_ss_drop1)
-cat("---\n")
-cat("Note: The Type I SS and Type III SS should be the same in \n")
-cat("      balanced crossover study.\n")
+colnames(BearAnova)<- c(" DF","   Type I SS", " Mean Square", " F Value", " Pr > F")
+show(BearAnova[2:4,])
 cat("\n")
-cat("Tests of Hypothesis for SUBJECT(SEQUENCE) as an error term\n")
-print(summary(aov(log(Cmax_ss) ~ prd*drug + Error(subj) , data=Data)))
+colnames(BearAnova)<- c(" DF"," Type III SS", " Mean Square", " F Value", " Pr > F")
+show(BearAnova[2:4,])
+cat("-----------------------------------------------------------\n")
+#
+# to adpat to SAS output
+#
+cat("\n")
+cat("Tests of Hypothesis using the Type I MS for \n")
+cat("SUBJECT(SEQUENCE) as an error term\n")
+show(summary(aov(log(Cmax_ss) ~ seq, data=Data)))
+cat("\n")
+cat("Tests of Hypothesis using the Type III MS for\n")
+cat("SUBJECT(SEQUENCE) as an error term\n")
+show(summary(aov(log(Cmax_ss) ~ seq, data=Data)))
 lnCmax<- lm(log(Cmax) ~ seq + subj:seq + prd + drug , data=TotalData)
 }
 else{
-cat("  Dependent Variable: log(Cmax)                           \n")
+cat("   Dependent Variable: log(Cmax)                           \n")
 lnCmax<- lm(log(Cmax)~ seq + subj:seq + prd + drug, data=TotalData)
 ### lnCmax<- aov(log(Cmax) ~ seq + subj:seq + prd + drug, data=TotalData)
 ### print(summary(lnCmax))
 cat("\n")
-cat("ANOVA Table incl. Type I SS\n")
 BearAnova=anova(lnCmax)
-show(BearAnova)
+row.names(BearAnova)[4]="subj(seq)"
+show(BearAnova[2:5,])
 cat("\n")
-cat("Type III SS\n")
-lnCmax_drop1 <- drop1(lnCmax, test="F")
-### row.names(lnCmax_drop1)[5]="subj(seq)"
-show(lnCmax_drop1)
+colnames(BearAnova)<- c(" DF","   Type I SS", " Mean Square", " F Value", " Pr > F")
+show(BearAnova[2:4,])
 cat("\n")
-cat("---\n")
-cat("Note: The Type I SS and Type III SS should be the same in \n")
-cat("      balanced crossover study.\n")
+colnames(BearAnova)<- c(" DF"," Type III SS", " Mean Square", " F Value", " Pr > F")
+show(BearAnova[2:4,])
+cat("-----------------------------------------------------------\n")
+#
+# to adpat to SAS output
+#
 cat("\n")
-cat("Tests of Hypothesis for SUBJECT(SEQUENCE) as an error term\n")
-print(summary(aov(log(Cmax) ~ prd*drug + Error(subj), data=TotalData)))
+cat("Tests of Hypothesis using the Type I MS for \n")
+cat("SUBJECT(SEQUENCE) as an error term\n")
+show(summary(aov(log(Cmax) ~ seq, data=TotalData)))
+cat("\n")
+cat("Tests of Hypothesis using the Type III MS for\n")
+cat("SUBJECT(SEQUENCE) as an error term\n")
+show(summary(aov(log(Cmax) ~ seq, data=TotalData)))
 }
-if(multiple){
 cat("\n")
+if(multiple){
 cat("Intra_subj. CV = 100*sqrt(abs(exp(MSResidual)-1)) =",formatC(100*sqrt(abs(exp(anova(lnCmax_ss)[5,3])-1)),format="f",digits=3),"%\n")
-cat("Inter_subj. CV = 100*sqrt(abs(exp((MSSubject(seq)-MSResidual)/2)-1)) =",formatC(100*sqrt(abs(exp((anova(lnCmax_ss)[4,3]-anova(lnCmax_ss)[5,3])/2)-1)),format="f",digits=3),"%\n")
+cat("Inter_subj. CV = 100*sqrt(abs(exp((MSSubject(seq)-MSResidual)/2)-1))\n")
+cat("               =",formatC(100*sqrt(abs(exp((anova(lnCmax_ss)[4,3]-anova(lnCmax_ss)[5,3])/2)-1)),format="f",digits=3),"%\n")
 cat("    MSResidual =",anova(lnCmax_ss)[5,3],"\n")
 cat("MSSubject(seq) =",anova(lnCmax_ss)[4,3],"\n")
 }
 else{
-cat("\n")
 cat("Intra_subj. CV = 100*sqrt(abs(exp(MSResidual)-1)) =",formatC(100*sqrt(abs(exp(anova(lnCmax)[5,3])-1)),format="f",digits=3),"%\n")
-cat("Inter_subj. CV = 100*sqrt(abs(exp((MSSubject(seq)-MSResidual)/2)-1)) =",formatC(100*sqrt(abs(exp((anova(lnCmax)[4,3]-anova(lnCmax)[5,3])/2)-1)),format="f",digits=3),"%\n")
+cat("Inter_subj. CV = 100*sqrt(abs(exp((MSSubject(seq)-MSResidual)/2)-1))\n")
+cat("               =",formatC(100*sqrt(abs(exp((anova(lnCmax)[4,3]-anova(lnCmax)[5,3])/2)-1)),format="f",digits=3),"%\n")
 cat("    MSResidual =",anova(lnCmax)[5,3],"\n")
 cat("MSSubject(seq) =",anova(lnCmax)[4,3],"\n")
 }
@@ -185,49 +256,74 @@ cat("\n")
 
 #lnAUC0t or lnAUCtau_ss
 
-cat("  Statistical analysis (ANOVA(lm))    \n")
-cat("--------------------------------------\n")
+cat("   Statistical analysis (ANOVA(lm))    \n")
+cat("-----------------------------------------------------------\n")
 if(multiple){
-cat("  Dependent Variable: log(AUCtau_ss) \n")
+cat("   Dependent Variable: log(AUCtau_ss) \n")
 cat("\n")
-cat("Type I SS\n")
 lnAUCtau_ss<- lm(log(AUCtau_ss) ~ seq + subj:seq + prd + drug , data=Data)
 BearAnova=anova(lnAUCtau_ss)
-show(BearAnova)
+row.names(BearAnova)[4]="subj(seq)"
+show(BearAnova[2:5,])
 cat("\n")
-cat("Type III SS\n")
-lnAUCtau_ss_drop1 <- drop1(lnAUCtau_ss, test="F")
-show(lnAUCtau_ss_drop1)
+colnames(BearAnova)<- c(" DF","   Type I SS", " Mean Square", " F Value", " Pr > F")
+show(BearAnova[2:4,])
 cat("\n")
-cat("Tests of Hypothesis for SUBJECT(SEQUENCE) as an error term\n")
-print(summary(aov(log(AUCtau_ss) ~ prd*drug + Error(subj) , data=Data)))
+colnames(BearAnova)<- c(" DF"," Type III SS", " Mean Square", " F Value", " Pr > F")
+show(BearAnova[2:4,])
+cat("-----------------------------------------------------------\n")
+#
+# to adpat to SAS output
+#
+cat("\n")
+cat("Tests of Hypothesis using the Type I MS for \n")
+cat("SUBJECT(SEQUENCE) as an error term\n")
+show(summary(aov(log(AUCtau_ss) ~ seq, data=Data)))
+cat("\n")
+cat("Tests of Hypothesis using the Type III MS for\n")
+cat("SUBJECT(SEQUENCE) as an error term\n")
+show(summary(aov(log(AUCtau_ss) ~ seq, data=Data)))
 lnAUC0t<- lm(log(AUC0t) ~ seq + subj:seq + prd + drug , data=TotalData)
 }
 else{
-cat("  Dependent Variable: log(AUC0t)     \n")
+cat("   Dependent Variable: log(AUC0t)     \n")
 cat("\n")
-cat("Type I SS\n")
 lnAUC0t<- lm(log(AUC0t) ~ seq + subj:seq + prd + drug , data=TotalData)
 BearAnova=anova(lnAUC0t)
-show(BearAnova)
+row.names(BearAnova)[4]="subj(seq)"
+show(BearAnova[2:5,])
 cat("\n")
-cat("Type III SS\n")
-lnAUC0t_drop1 <- drop1(lnAUC0t, test="F")
-show(lnAUC0t_drop1)
+colnames(BearAnova)<- c(" DF","   Type I SS", " Mean Square", " F Value", " Pr > F")
+row.names(BearAnova)[4]="subj(seq)"
+show(BearAnova[2:4,])
 cat("\n")
-cat("Tests of Hypothesis for SUBJECT(SEQUENCE) as an error term\n")
-print(summary(aov(log(AUC0t) ~ prd*drug + Error(subj) , data=TotalData)))
+colnames(BearAnova)<- c(" DF"," Type III SS", " Mean Square", " F Value", " Pr > F")
+show(BearAnova[2:4,])
+cat("-----------------------------------------------------------\n")
+#
+# to adpat to SAS output
+#
+cat("\n")
+cat("Tests of Hypothesis using the Type I MS for \n")
+cat("SUBJECT(SEQUENCE) as an error term\n")
+show(summary(aov(lnAUC0t ~ seq, data=TotalData)))
+cat("\n")
+cat("Tests of Hypothesis using the Type III MS for\n")
+cat("SUBJECT(SEQUENCE) as an error term\n")
+show(summary(aov(lnAUC0t ~ seq, data=TotalData)))
 }
+cat("\n")
 if(multiple){
 cat("Intra_subj. CV = 100*sqrt(abs(exp(MSResidual)-1)) =", formatC(100*sqrt(abs(exp(anova(lnAUCtau_ss)[5,3])-1)),format="f",digits=3),"%\n")
-cat("Inter_subj. CV = 100*sqrt(abs(exp((MSSubject(seq)-MSResidual)/2)-1)) =",formatC(100*sqrt(abs(exp((anova(lnAUCtau_ss)[4,3]-anova(lnAUCtau_ss)[5,3])/2)-1)),format="f",digits=3),"%\n")
+cat("Inter_subj. CV = 100*sqrt(abs(exp((MSSubject(seq)-MSResidual)/2)-1))\n")
+cat("               =",formatC(100*sqrt(abs(exp((anova(lnAUCtau_ss)[4,3]-anova(lnAUCtau_ss)[5,3])/2)-1)),format="f",digits=3),"%\n")
 cat("    MSResidual =",anova(lnAUCtau_ss)[5,3],"\n")
 cat("MSSubject(seq) =",anova(lnAUCtau_ss)[4,3],"\n")
 }
 else{
-cat("\n")
 cat("Intra_subj. CV = 100*sqrt(abs(exp(MSResidual)-1)) =", formatC(100*sqrt(abs(exp(anova(lnAUC0t)[5,3])-1)),format="f",digits=3),"%\n")
-cat("Inter_subj. CV = 100*sqrt(abs(exp((MSSubject(seq)-MSResidual)/2)-1)) =",formatC(100*sqrt(abs(exp((anova(lnAUC0t)[4,3]-anova(lnAUC0t)[5,3])/2)-1)),format="f",digits=3),"%\n")
+cat("Inter_subj. CV = 100*sqrt(abs(exp((MSSubject(seq)-MSResidual)/2)-1))\n")
+cat("               =",formatC(100*sqrt(abs(exp((anova(lnAUC0t)[4,3]-anova(lnAUC0t)[5,3])/2)-1)),format="f",digits=3),"%\n")
 cat("    MSResidual =",anova(lnAUC0t)[5,3],"\n")
 cat("MSSubject(seq) =",anova(lnAUC0t)[4,3],"\n")
 }
@@ -238,24 +334,36 @@ if(multiple){
  }
 else{
 #GLM_AUC0INF.txt
-cat("  Statistical analysis (ANOVA(lm))    \n")
-cat("--------------------------------------\n")
-cat("  Dependent Variable: log(AUC0INF)    \n")
+cat("   Statistical analysis (ANOVA(lm))    \n")
+cat("-----------------------------------------------------------\n")
+cat("   Dependent Variable: log(AUC0INF)    \n")
 cat("\n")
-cat("Type I SS\n")
 lnAUC0INF<- lm(log(AUC0INF) ~ seq + subj:seq + prd + drug , data=TotalData)
 BearAnova=anova(lnAUC0INF)
-show(BearAnova)
+row.names(BearAnova)[4]="subj(seq)"
+show(BearAnova[2:5,])
 cat("\n")
-cat("Type III SS\n")
-lnAUC0INF_drop1 <- drop1(lnAUC0INF, test="F")
-show(lnAUC0INF_drop1)
+colnames(BearAnova)<- c(" DF","   Type I SS", " Mean Square", " F Value", " Pr > F")
+show(BearAnova[2:4,])
 cat("\n")
-cat("Tests of Hypothesis for SUBJECT(SEQUENCE) as an error term\n")
-print(summary(aov(log(AUC0INF) ~ prd*drug + Error(subj) , data=TotalData)))
+colnames(BearAnova)<- c(" DF"," Type III SS", " Mean Square", " F Value", " Pr > F")
+show(BearAnova[2:4,])
+cat("-----------------------------------------------------------\n")
+#
+# to adpat to SAS output
+#
+cat("\n")
+cat("Tests of Hypothesis using the Type I MS for \n")
+cat("SUBJECT(SEQUENCE) as an error term\n")
+show(summary(aov(lnAUC0INF ~ seq, data=TotalData)))
+cat("\n")
+cat("Tests of Hypothesis using the Type III MS for\n")
+cat("SUBJECT(SEQUENCE) as an error term\n")
+show(summary(aov(lnAUC0INF ~ seq, data=TotalData)))
 cat("\n")
 cat("Intra_subj. CV = 100*sqrt(abs(exp(MSResidual)-1)) =",formatC(100*sqrt(abs(exp(anova(lnAUC0INF)[5,3])-1)),format="f",digits=3),"%\n")
-cat("Inter_subj. CV = 100*sqrt(abs(exp((MSSubject(seq)-MSResidual)/2)-1)) =",formatC(100*sqrt(abs(exp((anova(lnAUC0INF)[4,3]-anova(lnAUC0INF)[5,3])/2)-1)),format="f",digits=3),"%\n")
+cat("Inter_subj. CV = 100*sqrt(abs(exp((MSSubject(seq)-MSResidual)/2)-1))\n")
+cat("               =",formatC(100*sqrt(abs(exp((anova(lnAUC0INF)[4,3]-anova(lnAUC0INF)[5,3])/2)-1)),format="f",digits=3),"%\n")
 cat("    MSResidual =",anova(lnAUC0INF)[5,3],"\n")
 cat("MSSubject(seq) =",anova(lnAUC0INF)[4,3],"\n")     
 cat("\n")
